@@ -87,7 +87,6 @@ is_uuid_re = re.compile(
 
 
 class OSPDaemon:
-
     """Daemon class for OSP traffic handling.
 
     Every scanner wrapper should subclass it and make necessary additions and
@@ -808,9 +807,9 @@ class OSPDaemon:
         """Returns a dictionary with scan_id scan's progress information."""
         current_progress = dict()
 
-        current_progress[
-            'current_hosts'
-        ] = self.scan_collection.get_current_target_progress(scan_id)
+        current_progress['current_hosts'] = (
+            self.scan_collection.get_current_target_progress(scan_id)
+        )
         current_progress['overall'] = self.get_scan_progress(scan_id)
         current_progress['count_alive'] = self.scan_collection.get_count_alive(
             scan_id
@@ -818,12 +817,13 @@ class OSPDaemon:
         current_progress['count_dead'] = self.scan_collection.get_count_dead(
             scan_id
         )
-        current_progress[
-            'count_excluded'
-        ] = self.scan_collection.get_simplified_exclude_host_count(scan_id)
+        current_progress['count_excluded'] = (
+            self.scan_collection.get_simplified_exclude_host_count(scan_id)
+        )
+
         current_progress['count_total'] = self.scan_collection.get_count_total(
             scan_id
-        )
+        ) + self.scan_collection.get_finished_hosts_count(scan_id)
 
         logging.debug(
             "%s: Current progress: \n%s",
@@ -1257,6 +1257,13 @@ class OSPDaemon:
         the total count of host to be scanned."""
         self.scan_collection.update_count_total(scan_id, count_total)
 
+    def set_scan_total_excluded_hosts(
+        self, scan_id: str, excluded_hosts: int
+    ) -> None:
+        """Sets a scan's total excluded hosts. Allow the scanner to update
+        the total excluded count of hosts from the host to be scanned."""
+        self.scan_collection.update_count_excluded(scan_id, excluded_hosts)
+
     def clean_forgotten_scans(self) -> None:
         """Check for old stopped or finished scans which have not been
         deleted and delete them if the are older than the set value."""
