@@ -366,7 +366,6 @@ def safe_int(value: str) -> Optional[int]:
 
 
 class OpenVasVtsFilter(VtsFilter):
-
     """Methods to overwrite the ones in the original class."""
 
     def __init__(self, nvticache: NVTICache, notus: Notus) -> None:
@@ -435,7 +434,6 @@ class OpenVasVtsFilter(VtsFilter):
 
 
 class OSPDopenvas(OSPDaemon):
-
     """Class for ospd-openvas daemon."""
 
     def __init__(
@@ -493,25 +491,10 @@ class OSPDopenvas(OSPDaemon):
 
         self._mqtt_broker_address = mqtt_broker_address
         self._mqtt_broker_port = mqtt_broker_port
+        self._mqtt_broker_username = kwargs.get('mqtt_broker_username')
+        self._mqtt_broker_password = kwargs.get('mqtt_broker_password')
 
     def init(self, server: BaseServer) -> None:
-        notus_handler = NotusResultHandler(self.report_results)
-
-        if self._mqtt_broker_address:
-            client = MQTTClient(
-                self._mqtt_broker_address, self._mqtt_broker_port, "ospd"
-            )
-            daemon = MQTTDaemon(client)
-            subscriber = MQTTSubscriber(client)
-
-            subscriber.subscribe(ResultMessage, notus_handler.result_handler)
-            daemon.run()
-        else:
-            logger.info(
-                "MQTT Broker Adress empty. MQTT disabled. Unable to get Notus"
-                " results."
-            )
-
         self.scan_collection.init()
 
         server.start(self.handle_client_stream)
@@ -520,6 +503,27 @@ class OSPDopenvas(OSPDaemon):
 
         self.set_params_from_openvas_settings()
 
+        # Do not init MQTT daemon if Notus runs via openvasd.
+        if not self.scan_only_params.get("openvasd_server"):
+            notus_handler = NotusResultHandler(self.report_results)
+
+            if self._mqtt_broker_address:
+                client = MQTTClient(
+                    self._mqtt_broker_address, self._mqtt_broker_port, "ospd"
+                )
+                daemon = MQTTDaemon(client)
+                subscriber = MQTTSubscriber(client)
+
+                subscriber.subscribe(
+                    ResultMessage, notus_handler.result_handler
+                )
+                daemon.run()
+            else:
+                logger.info(
+                    "MQTT Broker Address empty. MQTT disabled. "
+                    "Unable to get Notus results."
+                )
+
         with self.feed_lock.wait_for_lock():
             self.update_vts()
             self.set_feed_info()
@@ -855,6 +859,7 @@ class OSPDopenvas(OSPDaemon):
                 or res["result_type"] == "HOST_END"
             )
             host_count = res["result_type"] == "HOSTS_COUNT"
+            host_excluded = res["result_type"] == "HOSTS_EXCLUDED"
             vt_aux = None
 
             # URI is optional and containing must be checked
@@ -865,6 +870,7 @@ class OSPDopenvas(OSPDaemon):
                 and not host_deny
                 and not start_end_msg
                 and not host_count
+                and not host_excluded
             ):
                 if not roid and res["result_type"] != 'ERRMSG':
                     logger.warning('Missing VT oid for a result')
@@ -957,6 +963,19 @@ class OSPDopenvas(OSPDaemon):
                 except TypeError:
                     logger.debug('Error processing total host count')
 
+            # To update total excluded hosts
+            if res["result_type"] == 'HOSTS_EXCLUDED':
+                try:
+                    total_excluded = int(res["value"])
+                    logger.debug(
+                        '%s: Set total excluded counted by OpenVAS: %d',
+                        scan_id,
+                        total_excluded,
+                    )
+                    self.set_scan_total_excluded_hosts(scan_id, total_excluded)
+                except TypeError:
+                    logger.debug('Error processing total excluded hosts')
+
         # Insert result batch into the scan collection table.
         if len(res_list):
             self.scan_collection.add_result_list(scan_id, res_list)
