@@ -1,20 +1,7 @@
 # -*- coding: utf-8 -*-
-# Copyright (C) 2014-2021 Greenbone Networks GmbH
+# SPDX-FileCopyrightText: 2014-2023 Greenbone AG
 #
 # SPDX-License-Identifier: AGPL-3.0-or-later
-#
-# This program is free software: you can redistribute it and/or modify
-# it under the terms of the GNU Affero General Public License as
-# published by the Free Software Foundation, either version 3 of the
-# License, or (at your option) any later version.
-#
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU Affero General Public License for more details.
-#
-# You should have received a copy of the GNU Affero General Public License
-# along with this program. If not, see <http://www.gnu.org/licenses/>.
 
 
 """ Access management for redis-based OpenVAS Scanner Database."""
@@ -72,6 +59,13 @@ class OpenvasDB:
     @classmethod
     def get_database_address(cls) -> Optional[str]:
         if not cls._db_address:
+            if not Openvas.check():
+                logger.error(
+                    'openvas executable not available. Please install openvas'
+                    ' into your PATH.'
+                )
+                sys.exit(1)
+
             settings = Openvas.get_settings()
 
             cls._db_address = settings.get('db_address')
